@@ -49,25 +49,31 @@ class KSYSGUARD_EXPORT ProcessModel : public QAbstractItemModel
     Q_ENUMS(Units)
 
     public:
-        ProcessModel(QObject* parent = 0, const QString &host = QString() );
-        virtual ~ProcessModel();
+        /** Storage for history values. PercentageHistoryRole returns a QVector of this. */
+        struct PercentageHistoryEntry {
+            unsigned long timestamp; // in ms, origin undefined as only the delta matters
+            float value;
+        };
+
+        ProcessModel(QObject* parent = nullptr, const QString &host = QString() );
+        ~ProcessModel() override;
 
         /* Functions for our Model for QAbstractItemModel*/
-        int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-        int columnCount ( const QModelIndex & parent = QModelIndex() ) const Q_DECL_OVERRIDE;
-        QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
-        QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
-        QModelIndex index ( int row, int column, const QModelIndex & parent = QModelIndex() ) const Q_DECL_OVERRIDE;
-        QModelIndex parent ( const QModelIndex & index ) const Q_DECL_OVERRIDE;
+        int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+        int columnCount ( const QModelIndex & parent = QModelIndex() ) const override;
+        QVariant data(const QModelIndex &index, int role) const override;
+        QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
+        QModelIndex index ( int row, int column, const QModelIndex & parent = QModelIndex() ) const override;
+        QModelIndex parent ( const QModelIndex & index ) const override;
 
-        bool hasChildren ( const QModelIndex & parent) const Q_DECL_OVERRIDE;
+        bool hasChildren ( const QModelIndex & parent) const override;
         /** Returns if (left < right), used by the sort-filter proxy model to sort the columns */
         bool lessThan( const QModelIndex & left, const QModelIndex & right) const;
 
         /* Functions for drag and drop and copying to clipboard, inherited from QAbstractItemModel */
-        QStringList mimeTypes() const Q_DECL_OVERRIDE;
-        QMimeData *mimeData(const QModelIndexList &indexes) const Q_DECL_OVERRIDE;
-        Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
+        QStringList mimeTypes() const override;
+        QMimeData *mimeData(const QModelIndexList &indexes) const override;
+        Qt::ItemFlags flags(const QModelIndex &index) const override;
 
         /* Functions for setting the model */
 
@@ -151,7 +157,7 @@ class KSYSGUARD_EXPORT ProcessModel : public QAbstractItemModel
             HeadingXTitle
         };
 
-        enum { UidRole = Qt::UserRole, SortingValueRole, WindowIdRole, PlainValueRole, PercentageRole };
+        enum { UidRole = Qt::UserRole, SortingValueRole, WindowIdRole, PlainValueRole, PercentageRole, PercentageHistoryRole };
 
         bool showTotals() const;
 
@@ -200,6 +206,9 @@ class KSYSGUARD_EXPORT ProcessModel : public QAbstractItemModel
         friend class ProcessModelPrivate;
 };
 
+Q_DECLARE_METATYPE(QVector<ProcessModel::PercentageHistoryEntry>);
+Q_DECLARE_TYPEINFO(ProcessModel::PercentageHistoryEntry, Q_PRIMITIVE_TYPE);
+
 #endif
 
 
