@@ -75,22 +75,32 @@ class ProgressBarItemDelegate : public QStyledItemDelegate
         ProgressBarItemDelegate(QObject *parent) : QStyledItemDelegate(parent) {
         }
 
-        void paint(QPainter *painter, const QStyleOptionViewItem &opt, const QModelIndex &index) const Q_DECL_OVERRIDE
+        void paint(QPainter *painter, const QStyleOptionViewItem &opt, const QModelIndex &index) const override
         {
             QStyleOptionViewItemV4 option = opt;
             initStyleOption(&option,index);
 
             float percentage = index.data(ProcessModel::PercentageRole).toFloat();
-            if (percentage >= 0)
-                drawPercentageDisplay(painter,option, percentage);
+            auto history = index.data(ProcessModel::PercentageHistoryRole).value<QVector<ProcessModel::PercentageHistoryEntry>>();
+            if (percentage >= 0 || history.size() > 1)
+                drawPercentageDisplay(painter, option, percentage, history);
             else
                 QStyledItemDelegate::paint(painter, option, index);
         }
 
     private:
-        inline void drawPercentageDisplay(QPainter *painter, QStyleOptionViewItemV4 &option, float percentage) const
+        inline void drawPercentageDisplay(QPainter *painter, QStyleOptionViewItemV4 &option, float percentage, const QVector<ProcessModel::PercentageHistoryEntry> &history) const
         {
             QStyle *style = option.widget ? option.widget->style() : QApplication::style();
+            const QRect &rect = option.rect;
+
+            const int HIST_MS_PER_PX = 100; // 100 ms = 1 px -> 1 s = 10 px
+            bool hasHistory = history.size() > 1;
+            // Make sure that more than one entry is visible
+            if (hasHistory) {
+                int width = (history.crbegin()->timestamp - (history.crbegin() + 1)->timestamp) / HIST_MS_PER_PX;
+                hasHistory = width < rect.width();
+            }
 
             // draw the background
             style->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, option.widget);
@@ -101,14 +111,46 @@ class ProgressBarItemDelegate : public QStyledItemDelegate
                 cg = QPalette::Inactive;
 
             //Now draw our percentage thingy
-            const QRect &rect = option.rect;
-            int size = qMin(percentage,1.0f) * rect.width();
+            int size = qMin(int(percentage * rect.height()), rect.height());
             if(size > 2 ) { //make sure the line will have a width of more than 1 pixel
                 painter->setPen(Qt::NoPen);
                 QColor color = option.palette.color(cg, QPalette::Link);
-                color.setAlpha(50);
+                color.setAlpha(33);
 
-                painter->fillRect( rect.x(), rect.y(), size, rect.height(), color);
+                painter->fillRect( rect.x(), rect.y() + rect.height() - size, rect.width(), size, color);
+            }
+
+            // Draw the history graph
+            if(hasHistory) {
+                QColor color = option.palette.color(cg, QPalette::Link);
+                color.setAlpha(66);
+                painter->setPen(Qt::NoPen);
+
+                QPainterPath path;
+                // From right to left
+                path.moveTo(rect.right(), rect.bottom());
+
+                int xNow = rect.right();
+                auto now = history.constLast();
+                int height = qMin(int(rect.height() * now.value), rect.height());
+                path.lineTo(xNow, rect.bottom() - height);
+
+                for(int index = history.size() - 2; index >= 0 && xNow > rect.left(); --index) {
+                    auto next = history.at(index);
+                    int width = (now.timestamp - next.timestamp) / HIST_MS_PER_PX;
+                    int xNext = qMax(xNow - width, rect.left());
+
+                    now = next;
+                    xNow = xNext;
+                    int height = qMin(int(rect.height() * now.value), rect.height());
+
+                    path.lineTo(xNow, rect.bottom() - height);
+                }
+
+                path.lineTo(xNow, rect.bottom());
+                path.lineTo(rect.right(), rect.bottom());
+
+                painter->fillPath(path, color);
             }
 
             // draw the text
@@ -150,9 +192,9 @@ class ProgressBarItemDelegate : public QStyledItemDelegate
 struct KSysGuardProcessListPrivate {
 
     KSysGuardProcessListPrivate(KSysGuardProcessList* q, const QString &hostName)
-        : mModel(q, hostName), mFilterModel(q), mUi(new Ui::ProcessWidget()), mProcessContextMenu(NULL), mUpdateTimer(NULL)
+        : mModel(q, hostName), mFilterModel(q), mUi(new Ui::ProcessWidget()), mProcessContextMenu(nullptr), mUpdateTimer(nullptr)
     {
-        mScripting = NULL;
+        mScripting = nullptr;
         mNeedToExpandInit = false;
         mNumItemsSelected = -1;
         mResortCountDown = 2; //The items added initially will be already sorted, but without CPU info.  On the second refresh we will have CPU usage, so /then/ we can resort
@@ -184,7 +226,7 @@ struct KSysGuardProcessListPrivate {
         jumpToSearchFilter->setShortcuts(QList<QKeySequence>() << QKeySequence::Find << '/');
     }
 
-    ~KSysGuardProcessListPrivate() { delete mUi; mUi = NULL; }
+    ~KSysGuardProcessListPrivate() { delete mUi; mUi = nullptr; }
 
     /** The number rows and their children for the given parent in the mFilterModel model */
     int totalRowCount(const QModelIndex &parent) const;
@@ -508,7 +550,7 @@ void KSysGuardProcessList::actionTriggered(QObject *object) {
     //Reset the text back to normal
     d->selectParent->setText(i18n("Jump to Parent Process"));
     QAction *result = qobject_cast<QAction *>(object);
-    if(result == 0) {
+    if(result == nullptr) {
         //Escape was pressed. Do nothing.
     } else if(result == d->renice) {
         reniceSelectedProcesses();
@@ -629,19 +671,19 @@ void KSysGuardProcessList::showColumnContextMenu(const QPoint &point){
             }
         }
     }
-    QAction *actionAuto = NULL;
-    QAction *actionKB = NULL;
-    QAction *actionMB = NULL;
-    QAction *actionGB = NULL;
-    QAction *actionPercentage = NULL;
-    QAction *actionShowCmdlineOptions = NULL;
-    QAction *actionShowTooltips = NULL;
-    QAction *actionNormalizeCPUUsage = NULL;
+    QAction *actionAuto = nullptr;
+    QAction *actionKB = nullptr;
+    QAction *actionMB = nullptr;
+    QAction *actionGB = nullptr;
+    QAction *actionPercentage = nullptr;
+    QAction *actionShowCmdlineOptions = nullptr;
+    QAction *actionShowTooltips = nullptr;
+    QAction *actionNormalizeCPUUsage = nullptr;
 
-    QAction *actionIoCharacters = NULL;
-    QAction *actionIoSyscalls = NULL;
-    QAction *actionIoActualCharacters = NULL;
-    QAction *actionIoShowRate = NULL;
+    QAction *actionIoCharacters = nullptr;
+    QAction *actionIoSyscalls = nullptr;
+    QAction *actionIoActualCharacters = nullptr;
+    QAction *actionIoShowRate = nullptr;
     bool showIoRate = false;
     if(index == ProcessModel::HeadingIoRead || index == ProcessModel::HeadingIoWrite)
         showIoRate = d->mModel.ioInformation() == ProcessModel::BytesRate ||
@@ -995,7 +1037,7 @@ void KSysGuardProcessList::setUpdateIntervalMSecs(int intervalMSecs)
     d->mUpdateIntervalMSecs = intervalMSecs;
     if(intervalMSecs <= 0) { //no point keep the timer around if we aren't updating automatically
         delete d->mUpdateTimer;
-        d->mUpdateTimer = NULL;
+        d->mUpdateTimer = nullptr;
         return;
     }
 
@@ -1464,7 +1506,7 @@ void KSysGuardProcessList::setScriptingEnabled(bool enabled)
         return;  //Nothing changed
     if(!enabled) {
         delete d->mScripting;
-        d->mScripting = NULL;
+        d->mScripting = nullptr;
     } else {
         d->mScripting = new Scripting(this);
         d->mScripting->hide();
