@@ -89,8 +89,8 @@ class Q_DECL_EXPORT KGraphicsSignalPlotter : public QGraphicsWidget
   Q_PROPERTY(int fillOpacity READ fillOpacity WRITE setFillOpacity)
 
   public:
-    KGraphicsSignalPlotter( QGraphicsItem *parent = 0);
-    virtual ~KGraphicsSignalPlotter();
+    KGraphicsSignalPlotter( QGraphicsItem *parent = nullptr);
+    ~KGraphicsSignalPlotter() override;
 
     /** \brief Add a new line to the graph plotter, with the specified color.
      *
@@ -447,11 +447,11 @@ class Q_DECL_EXPORT KGraphicsSignalPlotter : public QGraphicsWidget
 
   protected:
     /* Reimplemented */
-    void resizeEvent( QGraphicsSceneResizeEvent* event ) Q_DECL_OVERRIDE;
-    void paint( QPainter * p, const QStyleOptionGraphicsItem * option, QWidget * widget = 0 ) Q_DECL_OVERRIDE;
-    QSizeF sizeHint( Qt::SizeHint which, const QSizeF & constraint = QSizeF() ) const Q_DECL_OVERRIDE;
-    void changeEvent ( QEvent * event ) Q_DECL_OVERRIDE;
-    QPainterPath opaqueArea() const Q_DECL_OVERRIDE;
+    void resizeEvent( QGraphicsSceneResizeEvent* event ) override;
+    void paint( QPainter * p, const QStyleOptionGraphicsItem * option, QWidget * widget = nullptr ) override;
+    QSizeF sizeHint( Qt::SizeHint which, const QSizeF & constraint = QSizeF() ) const override;
+    void changeEvent ( QEvent * event ) override;
+    QPainterPath opaqueArea() const override;
 
 
   private:
