@@ -46,8 +46,8 @@ class GraphWidget;
 
 class KSignalPlotter;
 
-struct KSignalPlotterPrivate {
-
+class KSignalPlotterPrivate {
+public:
     KSignalPlotterPrivate( KSignalPlotter * q_ptr );
 
     void drawWidget(QPainter *p, const QRect &boundingBox);
@@ -144,7 +144,7 @@ struct KSignalPlotterPrivate {
 class GraphWidget : public QWidget {
   public:
     GraphWidget(QWidget *parent);
-    void paintEvent ( QPaintEvent * event ) Q_DECL_OVERRIDE;
+    void paintEvent ( QPaintEvent * event ) override;
 
     KSignalPlotterPrivate *signalPlotterPrivate;
 };
